==> foundation-android-1.6.0-rc01-sources.jar: androidMain/androidx/compose/foundation/OverscrollConfiguration.android.kt <==
/*
 * Copyright 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.foundation

import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.runtime.Stable
import androidx.compose.runtime.compositionLocalOf
import androidx.compose.ui.graphics.Color

/**
 * Metadata for overscroll effects for android platform.
 *
 * Note: this API is experimental and liable to be changed / removed. [glowColor] only applies
 * before Android S and so might be misleading to have in a generic configuration object, and
 * [drawPadding] may be moved to a different part of the API surface / removed depending on changes
 * to [OverscrollEffect].
 *
 * @param glowColor color for the glow effect, if the platform effect is a glow effect, otherwise
 * ignored.
 * @param drawPadding the amount of padding to apply from scrollable container bounds to
 * effect before drawing it
 */
@ExperimentalFoundationApi
@Stable
class OverscrollConfiguration(
    val glowColor: Color = Color(0xff666666), // taken from EdgeEffect.java defaults
    val drawPadding: PaddingValues = PaddingValues()
) {
    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as OverscrollConfiguration

        if (glowColor != other.glowColor) return false
        if (drawPadding != other.drawPadding) return false

        return true
    }

    override fun hashCode(): Int {
        var result = glowColor.hashCode()
        result = 31 * result + drawPadding.hashCode()
        return result
    }

    override fun toString(): String {
        return "OverscrollConfiguration(glowColor=$glowColor, drawPadding=$drawPadding)"
    }
}

/**
 * Composition local to provide configuration for scrolling containers down the
 * hierarchy. `null` means there will be no overscroll at all.
 *
 * Note: this is experimental since the underlying [OverscrollConfiguration] is also experimental.
 */
@Suppress("OPT_IN_MARKER_ON_WRONG_TARGET")
@ExperimentalFoundationApi
@get:ExperimentalFoundationApi
val LocalOverscrollConfiguration = compositionLocalOf<OverscrollConfiguration?> {
    OverscrollConfiguration()
}

==> foundation-android-1.7.6-sources.jar: androidMain/androidx/compose/foundation/OverscrollConfiguration.android.kt <==
/*
 * Copyright 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.foundation

import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.runtime.Stable
import androidx.compose.runtime.compositionLocalOf
import androidx.compose.ui.graphics.Color

/**
 * Metadata for overscroll effects for android platform.
 *
 * Note: this API is experimental and liable to be changed / removed. [glowColor] and [drawPadding]
 * only apply before Android S and so might be misleading to have in a generic configuration object.
 *
 * @param glowColor color for the glow effect, if the platform effect is a glow effect, otherwise
 * ignored.
 * @param drawPadding the amount of padding to apply from scrollable container bounds to
 * the effect before drawing it, if the platform effect is a glow effect, otherwise ignored.
 */
@ExperimentalFoundationApi
@Stable
class OverscrollConfiguration(
    val glowColor: Color = Color(0xff666666), // taken from EdgeEffect.java defaults
    val drawPadding: PaddingValues = PaddingValues()
) {
    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as OverscrollConfiguration

        if (glowColor != other.glowColor) return false
        if (drawPadding != other.drawPadding) return false

        return true
    }

    override fun hashCode(): Int {
        var result = glowColor.hashCode()
        result = 31 * result + drawPadding.hashCode()
        return result
    }

    override fun toString(): String {
        return "OverscrollConfiguration(glowColor=$glowColor, drawPadding=$drawPadding)"
    }
}

/**
 * Composition local to provide configuration for scrolling containers down the
 * hierarchy. `null` means there will be no overscroll at all.
 *
 * Note: this is experimental since the underlying [OverscrollConfiguration] is also experimental.
 */
@Suppress("OPT_IN_MARKER_ON_WRONG_TARGET")
@ExperimentalFoundationApi
@get:ExperimentalFoundationApi
val LocalOverscrollConfiguration = compositionLocalOf<OverscrollConfiguration?> {
    OverscrollConfiguration()
}
